#!/usr/bin/env python
# encoding: utf-8
"""
An example config file to input report generation parameters.
If you wish to examine all variables, omit variableOptions class and setOfVarOptions.

If one or more of these values is omitted they will use their default values.
Any other values/options/settings you try to input on the command line (such as --epsilon) will
be ignored. So please put any defaults you want that differ from the standard
defaults in your config file.

The meanings of these values are described below.

Created by evas Jun 2009.
Copyright (c) 2009 University of Wisconsin SSEC. All rights reserved.
"""

# some general options to control the input and output of the comparison
fileAName = './geocatL2.GOES-R.2005155.220000.ref_v3_20090601.hdf'
fileBName = './geocatL2.GOES-R.2005155.220000.hdf'
outputPath = './output/'
shouldIncludeImages = True

# the names of the latitude and longitude variables that will be used
longitudeVar = 'imager_prof_retr_abi_r4_generic1'
latitudeVar = 'imager_prof_retr_abi_r4_generic2'

# per variable defaults
defaultEpsilon = 0.0
defaultMissingValue = -999
defaultEpsilonFailureTolerance = None
defaultNonfiniteDataTolerance = 0.02

# a list of all the variables to analyze
setOfVariables = {}
setOfVariables['Total Totals'] = {
                                  'variable_name': 'imager_prof_retr_abi_total_totals_index',
                                  'epsilon': 1.0,
                                  'missing_value': None,
                                  'epsilon_failure_tolerance': 0.0,
                                  'nonfinite_data_tolerance': 0.0
                                  }
setOfVariables['Land Surface Temperature'] = {
                                  'variable_name': 'imager_prof_retr_abi_land_surface_temperature',
                                  'epsilon': 5.0,
                                  'missing_value': None
                                  # because the two tolerances are not defined here they will use the defaults
                                  # that are defined above
                                  }
setOfVariables['Total Precipitable Water, High'] = {
                                  'variable_name': 'imager_prof_retr_abi_total_precipitable_water_high'
                                  # because no other values are defined, this variable will use all defaults
                                  }

    

    